@@ -1,4 +1,7 @@
 package SQLite::Work::CGI;
+BEGIN {
+  $SQLite::Work::CGI::VERSION = '0.1003';
+}
 use strict;
 use warnings;
 
@@ -8,11 +11,7 @@ SQLite::Work::CGI - Report and update a SQLite database using CGI
 
 =head1 VERSION
 
-This describes version B<0.1002> of SQLite::Work::CGI.
-
-=cut
-
-our $VERSION = '0.1002';
+version 0.1003
 
 =head1 SYNOPSIS
 
@@ -327,12 +326,14 @@ sub do_single_update {
 	    if ($col ne $row_id_name)
 	    {
 		$update_values{$col} = $self->{cgi}->param($col);
+		$update_values{$col} =~ s/\r//g;
 	    }
 	}
     }
     else # update a single value
     {
 	$update_values{$update_field} = $self->{cgi}->param($update_field);
+	$update_values{$update_field} =~ s/\r//g;
     }
     if ($self->update_one_row(table=>$table,
 			      command=>$args{command},
@@ -409,8 +410,8 @@ sub do_add {
     my %vals = ();
     foreach my $col (@columns)
     {
-	my $val = $self->{cgi}->param($col);
-	$vals{$col} = $val;
+	$vals{$col} = $self->{cgi}->param($col);
+	$vals{$col} =~ s/\r//g;
     }
     if ($self->add_one_row(
 	table=>$table,
@@ -1726,4 +1727,4 @@ under the same terms as Perl itself.
 =cut
 
 1; # End of SQLite::Work::CGI
-__END__
+__END__
\ No newline at end of file
